@@ -1,6 +1,4 @@
 """Factories used to create data for testing."""
-from __future__ import absolute_import
-
 from .models import Group, Feed, Entry
 from .simple_test_server import PORT
 
@@ -8,19 +6,25 @@ import factory
 
 
 class GroupFactory(factory.DjangoModelFactory):
-    FACTORY_FOR = Group
+    class Meta:
+        model = Group
+        abstract = False
 
     name = factory.Sequence(lambda n: 'Test Group {0}'.format(n))
 
 
 class FeedFactory(factory.DjangoModelFactory):
-    FACTORY_FOR = Feed
+    class Meta:
+        model = Feed
+        abstract = False
 
     xml_url = factory.Sequence(lambda n: 'http://localhost:{0}/test{1}/feed'.format(PORT, n))
 
 
 class EntryFactory(factory.DjangoModelFactory):
-    FACTORY_FOR = Entry
+    class Meta:
+        model = Entry
+        abstract = False
 
     feed = factory.SubFactory(FeedFactory)
     title = factory.Sequence(lambda n: 'Test Entry {0}'.format(n))
